<?php
/**
 * Daily Insight Pro customizer default options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */


/**
 * Returns the default options for Daily Insight Pro.
 *
 * @since Daily Insight Pro 1.0
 * @return array An array of default values
 */
function daily_insight_pro_get_default_theme_options() {
	$theme_data  = wp_get_theme(); // get theme data
	$daily_insight_pro_default_options = array(

		//breaking-news
		'enable_breaking_news'			=> true,
		'breaking_news_type'			=> 'demo',
		'breaking_news_title'			=> esc_html__( 'Breaking News','daily-insight-pro' ),
		'breaking_news_no_of_posts'		=> 2,
		'breaking_news_category_type'	=> '',

		//main-slider
		'enable_main_slider'			=> 'static-frontpage',
		'main_slider_type'				=> 'demo',
		'main_slider_no_of_posts'		=> 2,
		'main_slider_category_type'		=> '',
		'slider_content_effect'         => 'cubic-bezier(0.250, 0.250, 0.750, 0.750)',
		'enable_slider_controls'        => true,
		'enable_slider_dragable'        => true,
		'slider_pause_on_hover'         => true,

		//latest-post
		'enable_latest_post'			=> 'static-frontpage',
		'latest_post_type'				=> 'demo',
		'latest_post_title'				=> esc_html__( 'Latest Post','daily-insight-pro' ),

		//category block one
		'enable_category_block_one'			=> true,
		'category_block_one_type'			=> 'demo',
		'category_block_one_icon'			=> 'fa-desktop',
		'category_block_one_category_type'	=> '',

		//category block two section one
		'enable_category_block_two'			=> true,
		'category_block_two_type'			=> 'demo',
		
		//category block two section one
		'category_block_two_section_one_no_of_posts'	=> 4,
		'category_block_two_section_one_icon'			=> 'fa-laptop',
		'category_block_two_section_one_category_type'	=> '',

		//category block two section two
		'category_block_two_section_two_icon'			=> 'fa-heart',
		'category_block_two_section_two_category_type'	=> '',

		//category block two section three
		'category_block_two_section_three_icon'			=> 'fa-globe',
		'category_block_two_section_three_category_type'=> '',

		//category block two section four
		'category_block_two_section_four_icon'			=> 'fa-hourglass',
		'category_block_two_section_four_category_type'	=> '',

		//category block two section five
		'category_block_two_section_five_icon'			=> 'fa-building-o',
		'category_block_two_section_five_category_type'	=> '',

		//category block three
		'enable_category_block_three'		=> true,
		'category_block_three_type'			=> 'demo',
		'category_block_three_icon'			=> 'fa-plane',
		'category_block_three_category_type'=> '',

		//category-block-four
		'enable_category_block_four'					=> true,
		'category_block_four_type'						=> 'demo',
		'category_block_four_no_of_posts'				=> 5,
		'category_block_four_category_type'				=> '',
		'enable_slider_controls_category_block_four'    => true,
		'enable_slider_dragable_category_block_four'    => true,
		'slider_pause_on_hover_category_block_four'     => true,

		//category block five
		'enable_category_block_five'		=> true,
		'category_block_five_type'			=> 'demo',
		'category_block_five_icon'			=> 'fa-globe',
		'category_block_five_category_type'	=> '',

		//category block six
		'enable_category_block_six'			=> true,
		'category_block_six_type'			=> 'demo',
		'category_block_six_title'			=> esc_html__( 'Latest Blog','daily-insight-pro' ),
		'category_block_six_category_type'	=> '',

		//category block seven
		'enable_category_block_seven'		=> true,
		'category_block_seven_type'			=> 'demo',
		'category_block_seven_title'		=> esc_html__( 'Trending News','daily-insight-pro' ),
		'category_block_seven_no_of_posts'  => 5,
		'category_block_seven_category_type'=> '',
		
		// Theme Options
		'theme_typography' 				=> 'default',
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'fa-spinner',
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'enable_sticky_menu'			=> false,
		'excerpt_length'           		=> 25,
		'breadcrumb_enable'         	=> false,
		'breadcrumb_separator'         	=> '/',
		'pagination_enable'         	=> false,
		'pagination_type'         		=> 'default',
		'copyright_text'           		=> sprintf( esc_html__( 'Copyright &copy; . All Rights Reserved','daily-insight-pro' ) ) . ' &#124; ' . esc_html( $theme_data->get( 'Name') ). '&nbsp;' . esc_html__( 'by', 'daily-insight-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( $theme_data->get( 'Author' ) ) .'</a>',
		'back_to_top'        			=> true,
		'reset_options'      			=> false,
		'enable_frontpage_content' 		=> true,

		'disable_primary_menu'			=> false,
		'disable_search'				=> false,
		'search_text'					=> esc_html__( 'Search..','daily-insight-pro' ),
		'readmore_text'					=> esc_html__( 'Read More','daily-insight-pro' ),
		// Color layout options
		'color_layout'                  => '#F5595A',
		'color_hover_layout'			=> '#F5595A',
		'archive_content_type'			=> 'excerpt',	
		'archive_image' 				=> false,
		'archive_meta' 					=> false,

		// Single Posts option
		'hide_related'					=> false,
		'hide_post_author_box'					=> false,
		'hide_post_category'					=> false,
		'hide_post_date'					=> false,
		'hide_post_views'					=> false,
		'hide_post_comment_count'					=> false,
		'hide_post_pagination'					=> false,
	);

	$output = apply_filters( 'daily_insight_pro_default_theme_options', $daily_insight_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}