<?php

/**
 * Category Block Five section
 *
 * This is the template for the content of Category Block Five section.
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_add_category_block_five' ) ) :
    /**
     * Add Category Block Five section
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_category_block_five() { 

        // Check if Category Block Five is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $category_block_five_enable = (bool)( $options['enable_category_block_five'] );
        if ( true !== $category_block_five_enable ) {
        return false;
        }
        // Get Category Block Five section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_category_block_five_section_details', $section_details );

        if ( empty( $section_details ) ) {
        return;
        }

        // Render Category Block Five section .
        daily_insight_pro_render_category_block_five_section( $section_details );
    }
endif;
add_action( 'daily_insight_pro_front_page_container_action', 'daily_insight_pro_add_category_block_five', 50 );




if ( ! function_exists( 'daily_insight_pro_get_category_block_five_section_details' ) ) :
    /**
     * Category Block Five section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Category Block Five section details.
    */
        function daily_insight_pro_get_category_block_five_section_details( $input ) {
            $options = daily_insight_pro_get_theme_options(); 

            // Category Block Five type
            $category_block_five_content_type    = $options['category_block_five_type'];
            $content = array();

            switch ( $category_block_five_content_type ) {

            case 'demo':
                $no_of_posts = 3; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'fashion-01.jpg', 'fashion-02.jpg', 'fashion-02.jpg', ); // An array of demo images
                $terms = array( esc_html__( 'Model','daily-insight-pro' ),esc_html__( 'Cloth accessories','daily-insight-pro' ),esc_html__( 'Cloth accessories','daily-insight-pro' ) );

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                $content[$index]['date']      = 'Aug,03 2016';
                $content[$index]['date_link'] = '#';
                $content[$index]['img_array'] = array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                $content[$index]['url']       = '#';
                $content[$index]['title']     = esc_html__( 'Proin gravida nibh vel velit  auctor aliquet. Aenean sollicit.','daily-insight-pro' );
                $content[$index]['terms']     = $terms[$index];
            }
            break;

            case 'category':

                $category = !empty( $options['category_block_five_category_type'] ) ? absint( $options['category_block_five_category_type'] ) : '';

                if ( ! empty( $category ) ) {

                    $args = array(
                        'cat'                 => $category,
                        'posts_per_page'      => 3,
                    );
                }
                if( !empty( $args ) ) :

                    $custom_posts = get_posts( $args );

                    $index = 0;
                    foreach ( $custom_posts as $key => $custom_post ) {

                        if ( has_post_thumbnail( $custom_post->ID ) ) {
                            if ( $index == 0 ) {
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-fashion-portrait' );
                            } else {
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-fashion-landscape' );
                            }
                        }
                        else {
                            if ( $index == 0 ) {
                                $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-375x500.jpg' );
                            }
                            else{
                                $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-375x240.jpg' );
                            }
                        }

                        if ( isset( $img_array ) ) {
                        $content[$index]['img_array'] = $img_array;
                        }
                        $year  = get_the_time('Y', $custom_post->ID );
                        $month = get_the_time('m', $custom_post->ID );
                        $day   = get_the_time('d', $custom_post->ID );

                        $content[$index]['date_link'] = get_day_link( $year, $month, $day );
                        $content[$index]['date']      = get_the_date( '' , $custom_post );
                        $content[$index]['title']     = get_the_title( $custom_post->ID );
                        $content[$index]['url']       = get_the_permalink( $custom_post->ID );
                        $content[$index]['terms']     = get_the_category( $custom_post->ID ); 
                        $index++;
                    }
                endif;
            break;

            default:
            break;
        }
        if ( ! empty( $content ) ) {
        $input = $content;
        }
        return $input; 
     }
endif;
// Category Block Five section content details.
add_filter( 'daily_insight_pro_filter_category_block_five_section_details', 'daily_insight_pro_get_category_block_five_section_details' );

if ( ! function_exists( 'daily_insight_pro_render_category_block_five_section' ) ) :
    /**
     * Start section Category Block Five
     *
     * @return string Category Block Five content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_category_block_five_section( $content_details = array() ) {

        $options       = daily_insight_pro_get_theme_options();
        $content_type  = $options['category_block_five_type'];
        $section_link  = get_category_link( $options['category_block_five_category_type'] );
        $section_title = get_cat_name( $options['category_block_five_category_type'] );
        $index         = 0;
        $count         = count( $content_details );

        if ( empty( $content_details ) ) {
        return;
        } ?>

        <section id="fashion-category" class="page-section two-columns">
        <?php
        $section_title = ( $options['category_block_five_type'] == 'demo' ) ? esc_html__( 'Fashion','daily-insight-pro' ) : $section_title;
        $section_icon =  ( $options['category_block_five_type'] == 'demo' ) ? 'fa-globe' : $options['category_block_five_icon'];
        $section_link =  ( $options['category_block_five_type'] == 'demo' ) ? esc_html__( '#','daily-insight-pro' ) : $section_link;
            if( ! empty ( $section_title ) ) : ?>
            <header class="entry-header">
                <h2 class="entry-title category-title"><i class="fa <?php echo esc_attr( $section_icon ); ?>"></i><?php echo esc_html( $section_title ); ?></h2> 
                <a href="<?php echo esc_url( $section_link ); ?>" class="view-more"><?php esc_html_e('View more','daily-insight-pro' ); ?></a> 
            </header>
            <?php endif; ?>

            <div class="entry-content row no-margin-top">
                <div class="column-wrapper">
                <?php foreach ($content_details as $content ) { ?>
                    <div class="post-category">
                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                        <div class="overlay"></div></a>
                        <div class="category-contents-wrapper">
                            <h2 class="title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2> 
                            <?php
                            $post_categories = $content['terms'];
                            if( !empty ( $post_categories ) ) :
                                if( 'demo' == $content_type ) { ?>
                                    <a class="category" href="#"><?php echo esc_html( $post_categories ); ?></a>                        
                                <?php }
                                else { 
                                    foreach ( $post_categories as $post_category ) {
                                        $category_id   = $post_category->term_id;
                                        $category_name = $post_category->name;
                                        $category_url  = get_category_link( $category_id );
                                    ?>
                                    <a class="category" href="<?php echo esc_url( $category_url ); ?>"><?php echo esc_html( $category_name ); ?></a>
                                <?php } }
                            endif; ?>
                            <a href="<?php echo esc_url( $content['date_link'] ); ?>"><time><?php echo esc_html( $content['date'] ); ?></span></a>
                        </div><!-- .category-contents-wrapper -->
                    </div><!-- .post-category -->
                <?php if( $index == 0 ) : ?>
                </div><!-- .column-wrapper -->
                <div class="column-wrapper">
                <?php endif;
                $index++; } 
                if( ( $count ) == $index ) : ?>
                </div><!-- .column-wrapper -->
                <?php endif;?>
            </div><!-- .entry-content -->
        </section><!-- #fashion-category -->
     <?php
     }
endif;