<?php
/**
 * Daily Insight Pro widgets inclusion
 *
 * This is the template that includes all custom widgets of Daily Insight Pro
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! class_exists( 'Daily_Insight_Pro_Popular_Post' ) ) :

     
    class Daily_Insight_Pro_Popular_Post extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $tp_widget_popular_post = array(
                'classname'   => 'daily_insight_pro_popular_post',
                'description' => esc_html__( 'Retrive top viewed posts.', 'daily-insight-pro' ),
            );
            parent::__construct( 'daily_insight_pro_popular_post', esc_html__( 'TP : Popular Posts','daily-insight-pro' ), $tp_widget_popular_post );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {
            // outputs the content of the widget
            if ( ! isset( $args['widget_id'] ) ) {
                $args['widget_id'] = $this->id;
            }

            $tp_title  = ( ! empty( $instance['title'] ) ) ? ( $instance['title'] ) : esc_html__( 'Popular', 'daily-insight-pro' );
            $tp_number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;

            echo $args['before_widget'];
                if ( ! empty( $tp_title ) ) {
                    echo $args['before_title'] . esc_html( $tp_title ) . $args['after_title'];
                }
            $popular_args = array(
                'post_type'             => 'post',
                'posts_per_page'        => $tp_number,
                'meta_key'              => 'post_views_count',
                'orderby'               => 'meta_value_num',
                'order'                 => 'DESC',
                'ignore_sticky_posts'   => true
                );

            $wp_query = get_posts( $popular_args );
            foreach ( $wp_query as $post ) :
            ?>
                <div class="popular-post os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s">
                    <div class="image">
                        <a href="<?php the_permalink( $post->ID ); ?>">
                            <?php 
                            if ( has_post_thumbnail( $post->ID ) ) :
                                $image = get_the_post_thumbnail( $post->ID, $size = 'thumbnail', array( 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
                            else:
                                $image = '<img src="'. get_template_directory_uri().'/assets/img/smallthumb.png" alt="'. esc_attr( $post->post_title ) .'">';
                            endif; 
                            echo $image;
                            ?>
                        </a>
                    </div><!-- end .image -->
                    <div class="desc">
                        <a href="<?php the_permalink( $post->ID ); ?>"><h3><?php echo esc_html( $post->post_title ); ?></h3></a>
                        <span class="date"><?php echo esc_html( get_the_date( '', $post->ID ) ); ?></span>
                    </div><!-- end .desc -->
                </div><!-- popular-post -->
            <?php
            endforeach;
            echo $args['after_widget'];
        }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {
            $tp_title      = isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Popular', 'daily-insight-pro' );
            $tp_number     = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
           ?>

           <p>
               <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'daily-insight-pro' ); ?></label>
               <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $tp_title ); ?>" />
           </p>

           <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'daily-insight-pro' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="7" value="<?php echo absint( $tp_number ); ?>" size="3" />
           </p>

           <?php
        }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        public function update( $new_instance, $old_instance ) {
            // processes widget options to be saved
            $instance           = $old_instance;
            $instance['title']  = sanitize_text_field( $new_instance['title'] );
            $instance['number'] = (int) $new_instance['number'];
           
            return $instance;
        }
    }
endif;

function daily_insight_pro_register_popular_post_widget() {
    register_widget( 'Daily_Insight_Pro_Popular_Post' );
}
add_action( 'widgets_init', 'daily_insight_pro_register_popular_post_widget' );